<?php
/**
* The private messaging system
* @package	OpenBASE
* @author 	David Branco <David@NeoeliteUSA.com>
*/

// require core
require_once("../core.inc.php");

defined("_IN_OB_") or die("Access Restricted.");

//Check if the user is logged in
Loggin_Check();

// instantiate PrivMsgs class
require_once($root_prefix . "classes/privmsgs.class.php");
$privmsgs = new PrivMsgs();

//Add Navigation
require_once($root_prefix . "nav.php");

// Set Session ID on some templates. Allows for multiple windows open.
$tpl->assign('sessionid', session_id());

//Check to see if the private messaging system is disabled
if(!$config_db->GetConfig('AllowPrivateMessaging')){SystemMessage(GEN_DISABLED, 1);}

// check for url service requests
if(isset($_GET['m_op']) && !empty($_GET['m_op']) && is_string($_GET['m_op']) && !is_numeric($_GET['m_op']))
{
	switch($_GET['m_op'])
	{
		case 'read':
			if(isset($_GET['msg']) && !empty($_GET['msg']) && is_numeric($_GET['msg']))
			{
				$msg_id = $_GET['msg'];
				$msg = $privmsgs->fetchmessage($msg_id);
				if(empty($msg))
				{
					SystemMessage(_PRIVATEMESSAGES_READ_NOT_FOUND, 1);
				}
				else
				{
					$privmsgs->markmessageold($msg_id);
					$tpl->assign_by_ref('privmsg', $msg);
					$tpl->DisplayPage('privatemessages_read.tpl');
				}
			}
			break;
		case 'delete':
			if(isset($_GET['msg']) && !empty($_GET['msg']) && is_numeric($_GET['msg']))
			{
				$msg = $privmsgs->deletemessage($_GET['msg']);
				if(empty($msg))
				{
					SystemMessage(_PRIVATEMESSAGES_DELETE_NOT_FOUND, 1);
				}
				else
				{
					$tpl->assign('message', _PRIVATEMESSAGES_PM_DELETED);
					$tpl->DisplayPage("privatemessages_deleted.tpl");
				}
			}
			break;
		case 'compose':
			// check if posting direct to a client
			if(isset($_GET['cid']) && !empty($_GET['cid']) && is_numeric($_GET['cid']))
			{
				$tpl->assign('privmsgs_clientisset', 'true');
				// check for valid target client
				if(!$privmsgs->isvalidclient($_GET['cid']))
				{
					SystemMessage(_PRIVATEMESSAGES_TARGET_NOTFOUND, 1);
				}
				$tpl->assign('privmsgs', $privmsgs->fetchclient($_GET['cid'], 'private_message'));
			}
			else
			{
				// otherwise no client has been chosen, so set To: field as input form
				$tpl->assign('privmsgs_clientisset', 'false');
			}
			$tpl->DisplayPage('privatemessages_compose.tpl');
			break;
	}
}

// check for form submissions
elseif(isset($_POST['m_op']) && !empty($_POST['m_op']) && is_string($_POST['m_op']) && !is_numeric($_POST['m_op']))
{
	switch($_POST['m_op'])
	{
		case 'compose':
			// check incoming login name
			$_POST['cname'] = quote_smart($_POST['cname']); // remove html
			if(!isset($_POST['cname']) || empty($_POST['cname']) || !is_string($_POST['cname']) || !$privmsgs->isvalidclientname($_POST['cname']))
			{
				SystemMessage(_PRIVATEMESSAGES_TARGET_NOTFOUND, 1);
			}
			// eliminate self-posting - there's always one joker out there...
			if($_POST['cname'] == $client->username)
			{
				SystemMessage(_PRIVATEMESSAGES_PM_SELF, 1);
			}

			// check subject and text
			$_POST['c_subject'] = quote_smart(htmlspecialchars($_POST['c_subject']));
			//$_POST['c_text'] = quote_smart($safehtml->parse($_POST['c_text']));
			$_POST['c_text'] = quote_smart($_POST['c_text']);

			if(!isset($_POST['c_subject']) || empty($_POST['c_subject']) || !is_string($_POST['c_subject']))
			{
				$_POST['c_subject'] = '|)(Untitled)(|'; // append default subject line...
			}
			if(!isset($_POST['c_text']) || empty($_POST['c_text']) || !is_string($_POST['c_text']))
			{
				SystemMessage(_PRIVATEMESSAGES_EMPTY_POST, 1);
			}
			// fetch the target's client_id
			$target_id = $privmsgs->fetchidfromname($_POST['cname']);
			// here we should do some basic escaping - but no sec class just yet, so off we go
			$thisMsg = array();
			$thisMsg['privmsgs_to'] = $target_id;
			$thisMsg['privmsgs_from'] = $client->client_id;
			$thisMsg['privmsgs_from_name'] = $client->username;
			$thisMsg['privmsgs_status'] = 'New';
			$thisMsg['privmsgs_subject'] = $_POST['c_subject'];
			$thisMsg['privmsgs_text'] = $_POST['c_text'];
			$privmsgs->addmessage($thisMsg);
			// display confirm
			$message = str_replace("%s", $_POST['cname'], _PRIVATEMESSAGES_PM_SENT);
			SystemMessage($message, null, 1);
		break;
	}
}
else
{
	// fetch messages
	$msgs = $privmsgs->fetchmessages();
	$msgs_count = $privmsgs->countallmessages();
    	$oldmsgs = $privmsgs->countreadmessages();
    	$tpl->assign('privmsgs_newnum', ($msgs_count - $oldmsgs));
	$tpl->assign('privmsgs_totalnum', $msgs_count);
	$tpl->assign_by_ref('privmsgs', $msgs);
	$tpl->DisplayPage("privatemessages.tpl");
}
?>