<?php
defined("_IN_OB_") or die("Access Restricted.");

/**
* Handles the downloading and download tracking system
* @package	OpenBASE
* @author 	David Branco <David@NeoeliteUSA.com>
* @access 	public
*/
class Download_Tracker {
	
	var $download_DB = array();
	var $download_stats_DB = array();

    /**
    * Turns the downloads and downloadstats databases into a array for better proformace and less querys
    *
    * @return   string
    * @access   public
    */
	function StartTracker() 
	{
		global $db, $dbprefix, $tpl, $config_db;
		$registry = &Registry::instance();
		$this->tpl_static =& $tpl;
		
		if (!$config_db->GetConfig('AllowDownloads')){return false;}
		
	    	$this->download_DB = $db->GetAll("SELECT * FROM `" . $dbprefix . "_downloads` ORDER BY `download_id` DESC");
		
	    	$this->download_stats_DB = $db->GetAll("SELECT * FROM `" . $dbprefix . "_downloadstats` ORDER BY `stat_id` DESC");
		
		$this->tpl_static->assign('download_tracker', $this->download_DB);
		$this->tpl_static->assign('downloadstats_tracker', $this->download_stats_DB);
		
		if (is_array($this->download_DB) && is_array($this->download_stats_DB)) {
			return true;
		}else{
			return false;
		}
	}

    /**
    * Fetchs downloads created by the specific author
    *
    * @return   string
    * @access   public
    */
	function fetchdownloadsfromauthor($c_id) {
		$downloads = array();
		for($i=0;$i<count($this->download_DB);$i++)
		{
			if ($this->download_DB[$i]['author_id'] == $c_id)
			{
				array_push($downloads, $this->download_DB[$i]);
			}
		}
		if(empty($downloads))
		{
			return false;
		}
		return $downloads;
	}

    /**
    * Fetchs every download in the table
    *
    * @return   string
    * @access   public
    */
	function fetchdownloads() {
		if(empty($this->download_DB))
		{
			return false;
		}
		return $this->download_DB;
	}
	
    /**
    * Checks to see if the file exists
    *
    * @return   string
    * @access   public
    */
	function VerifyDownload($download_id) {
		for($i=0;$i<count($this->download_DB);$i++)
		{
			if ($this->download_DB[$i]['download_id'] == $download_id)
			{
				return true;
			}
		}
		return false;
	}

    /**
    * Checks the download image verification string
    *
    * @return   string
    * @access   public
    */
	function check_image($our_var, $their_var) {
		global $db;
		if (strtolower($our_var) == strtolower($their_var)){
			return 1;
		}else{
			return 0;
		}
	}

    /**
    * Starts downloading a tracked file with the correct headers plus allows for download ranging
    * Thank you, Jon <http://us3.php.net/header>
    * @return   int
    * @access   public
    */
	function DownloadFile ($download_id)
	{
		global $db, $dbprefix, $config_db;
	  	$status = 0;
	    	
	    	if (!$config_db->GetConfig('AllowDownloads')){return false;}
	    	
	    	$db->Execute("UPDATE `" . $dbprefix . "_downloads` SET hits=hits+1 WHERE download_id='". $download_id . "'");
		
		for($i=0;$i<count($this->download_DB);$i++)
		{
			if ($this->download_DB[$i]['download_id'] == $download_id)
			{
				$file = $this->download_DB[$i]['location'];
				$name = $this->download_DB[$i]['name'];
				break;
			}
		}
		/** Need to check if file exists */
		//if (($file != NULL) && file_exists($file))
	  	if ($file != NULL)
	  	{
	   		if(isset($_SERVER['HTTP_USER_AGENT']) && preg_match("/MSIE/", $_SERVER['HTTP_USER_AGENT']))
	   		{
	     			// IE Bug in download name workaround
	     			ini_set( 'zlib.output_compression','Off' );
	   		}
	   		
			//header ('Content-type: ' . mime_content_type($file));
			header ('Content-Disposition: attachment; filename="'.basename($file).'"');
			header ('Expires: '.gmdate("D, d M Y H:i:s", mktime(date("H")+2, date("i"), date("s"), date("m"), date("d"), date("Y"))).' GMT');
			header ('Accept-Ranges: bytes');
			header ('Cache-control: private');                 
			header ('Pragma: private');

			$date = date('d M Y h:i:s a');
			$db->Execute("INSERT INTO `" . $dbprefix . "_downloadstats` SET download_id='" . $download_id . "', ip='" . $_SERVER["REMOTE_ADDR"] . "', date='" . $date . "'");
			$this->DownloadAlert($download_id, $name, $_SERVER["REMOTE_ADDR"], $date);
	
			$size = filesize($file);
			if(isset($_SERVER['HTTP_RANGE'])) 
			{
				list($a, $range) = explode("=",$_SERVER['HTTP_RANGE']);
				//if yes, download missing part
				str_replace($range, "-", $range);
				$size2 = $size-1;
				$new_length = $size2-$range;
				header("HTTP/1.1 206 Partial Content");
				header("Content-Length: $new_length");
				header("Content-Range: bytes $range$size2/$size");
	  		}else{
				$size2=$size-1;
	     			header("Content-Range: bytes 0-$size2/$size");
	     			header("Content-Length: ".$size);
	   		}

			if ($file = fopen($file, 'r')) 
			{
				while(!feof($file) and (connection_status()==0))
				{
					print(fread($file, 1024*8));
					flush();
				}
				$status = (connection_status() == 0);
				fclose($file);
			}
		}
		return($status);
	}

    /**
    * Starts downloading a tracked stream with the correct headers plus allows for stream ranging
    * Thank you, Jon <http://us3.php.net/header>
    * @return   int
    * @access   public
    */
	function DownloadStream(&$download_id)
	{
		global $db, $dbprefix, $config_db;
		$status = 0;
	    	
	    	if (!$config_db->GetConfig('AllowDownloads')){return false;}
	    	
	    	$db->Execute("UPDATE `" . $dbprefix . "_downloads` SET hits=hits+1 WHERE download_id='". $download_id . "'");
		
		for($i=0;$i<count($this->download_DB);$i++)
		{
			if ($this->download_DB[$i]['download_id'] == $download_id)
			{
				$stream = $this->download_DB[$i]['location'];
				$name = $this->download_DB[$i]['name'];
				break;
			}
		}
	  			
		$size = strlen($stream);
		if ($size > 0)
		{
			if(isset($_SERVER['HTTP_USER_AGENT']) && preg_match("/MSIE/", $_SERVER['HTTP_USER_AGENT']))
	   		{
				// IE Bug in download name workaround
				ini_set( 'zlib.output_compression','Off' );
			}
			
			//header ('Content-type: ' . mime_content_type($stream));
			header ('Content-type: ' . $mimetype);
			header ('Content-Disposition: attachment; filename="'.basename($stream).'"');
			header ('Expires: '.gmdate("D, d M Y H:i:s", mktime(date("H")+2, date("i"), date("s"), date("m"), date("d"), date("Y"))).' GMT');
			header ('Accept-Ranges: bytes');
			header ('Cache-control: private');                 
			header ('Pragma: private');

			$date = date('d M Y h:i:s a');
			$db->Execute("INSERT INTO `" . $dbprefix . "_downloadstats` SET download_id='" . $download_id . "', ip='" . $_SERVER["REMOTE_ADDR"] . "', date='" . $date . "'");
			$this->DownloadAlert($download_id, $name, $_SERVER["REMOTE_ADDR"], $date);

			if(isset($_SERVER['HTTP_RANGE'])) {
				list($a, $range) = explode("=",$_SERVER['HTTP_RANGE']);
				//if yes, download missing part
				str_replace($range, "-", $range);
				$size2 = $size-1;
				$new_length = $size2-$range;
				header("HTTP/1.1 206 Partial Content");
				header("Content-Length: $new_length");
				header("Content-Range: bytes $range$size2/$size");
			}else{
				$size2=$size-1;
				header("Content-Range: bytes 0-$size2/$size");
				header("Content-Length: ".$size);
			}

			// Dump the content.
			echo $stream;
			$status = 1;
		}
		return($status);
	}

    /**
    * Alerts the administrator about the new download
    * @return   true
    * @access   public
    */
	function DownloadAlert ($download_id, $name, $ip, $date)
	{
		global $db, $dbprefix, $config_db, $admin_info;
		if (!$config_db->GetConfig('AllowDownloads')){return false;}
		if(!$config_db->GetConfig('DownloadEmailAlerts')){return false;}
		
		$message = _DOWNLOAD_CLASS_TITLE." <br />".
		_DOWNLOAD_CLASS_FILENAME." ".$name." <br />".
		_DOWNLOAD_CLASS_FILEID." ".$download_id." <br />".
		"IP: ".$ip." <br />".
		_DOWNLOAD_CLASS_DATETIME." ".$date." <br />".
		_DOWNLOAD_CLASS_THANKYOU." - OpenBASE";
		
		if($config_db->GetConfig('email_method') == "Mail()")
		{
			if(!mail($admin_info['email'], $config_db->GetConfig('DownloadEmailTitle'), $message, '',"From: " . $config_db->GetConfig('DownloadEmailAddress'))){return false;}
		}else{
			$phpmailer->From	= $config_db->GetConfig('DownloadEmailAddress');
			$phpmailer->AddAddress($admin_info['email']);
			$phpmailer->Subject	= $config_db->GetConfig('DownloadEmailTitle');
			$phpmailer->Body 	= $message;
			if(!$phpmailer->Send()){return false;}
		}
		return true;
	}
	
    /**
    * Starts downloading a untracked file with the correct headers plus allows for download ranging
    * Thank you, Jon <http://us3.php.net/header>
    * @return   int
    * @access   public
    */
	function DownloadUntrackedFile ($file)
	{
		global $config_db;
	  	$status = 0;
		if (!$config_db->GetConfig('AllowDownloads')){return false;}
		
		/** Need to check if file exists */
		//if (($file != NULL) && file_exists($file))
	  	if ($file != NULL)
	  	{
	   		if(isset($_SERVER['HTTP_USER_AGENT']) && preg_match("/MSIE/", $_SERVER['HTTP_USER_AGENT']))
	   		{
	     			// IE Bug in download name workaround
	     			ini_set( 'zlib.output_compression','Off' );
	   		}
	   		
			//header ('Content-type: ' . mime_content_type($file));
			header ('Content-Disposition: attachment; filename="'.basename($file).'"');
			header ('Expires: '.gmdate("D, d M Y H:i:s", mktime(date("H")+2, date("i"), date("s"), date("m"), date("d"), date("Y"))).' GMT');
			header ('Accept-Ranges: bytes');
			header ('Cache-control: private');                 
			header ('Pragma: private');

			$size = filesize($file);
			if(isset($_SERVER['HTTP_RANGE'])) 
			{
				list($a, $range) = explode("=",$_SERVER['HTTP_RANGE']);
				//if yes, download missing part
				str_replace($range, "-", $range);
				$size2 = $size-1;
				$new_length = $size2-$range;
				header("HTTP/1.1 206 Partial Content");
				header("Content-Length: $new_length");
				header("Content-Range: bytes $range$size2/$size");
	  		}else{
				$size2=$size-1;
	     			header("Content-Range: bytes 0-$size2/$size");
	     			header("Content-Length: ".$size);
	   		}

			if ($file = fopen($file, 'r'))
			{
				while(!feof($file) and (connection_status()==0))
				{
					print(fread($file, 1024*8));
					flush();
				}
				$status = (connection_status() == 0);
				fclose($file);
			}
		}
		return($status);
	}

    /**
    * Starts downloading a untracked stream with the correct headers plus allows for stream ranging
    * Thank you, Jon <http://us3.php.net/header>
    * @return   int
    * @access   public
    */
	function DownloadUntrackedStream(&$stream)
	{
		global $config_db;
		$status = 0;
		if (!$config_db->GetConfig('AllowDownloads')){return false;}
		$size = strlen($stream);
		if ($size > 0)
		{
			if(isset($_SERVER['HTTP_USER_AGENT']) && preg_match("/MSIE/", $_SERVER['HTTP_USER_AGENT']))
	   		{
				// IE Bug in download name workaround
				ini_set( 'zlib.output_compression','Off' );
			}
			
			//header ('Content-type: ' . mime_content_type($stream));
			header ('Content-type: ' . $mimetype);
			header ('Content-Disposition: attachment; filename="'.basename($stream).'"');
			header ('Expires: '.gmdate("D, d M Y H:i:s", mktime(date("H")+2, date("i"), date("s"), date("m"), date("d"), date("Y"))).' GMT');
			header ('Accept-Ranges: bytes');
			header ('Cache-control: private');                 
			header ('Pragma: private');

			if(isset($_SERVER['HTTP_RANGE'])) {
				list($a, $range) = explode("=",$_SERVER['HTTP_RANGE']);
				//if yes, download missing part
				str_replace($range, "-", $range);
				$size2 = $size-1;
				$new_length = $size2-$range;
				header("HTTP/1.1 206 Partial Content");
				header("Content-Length: $new_length");
				header("Content-Range: bytes $range$size2/$size");
			}else{
				$size2=$size-1;
				header("Content-Range: bytes 0-$size2/$size");
				header("Content-Length: ".$size);
			}

			// Dump the content.
			echo $stream;
			$status = 1;
		}
		return($status);
	}
}
?>