<div style="border: 1px outset #666666; padding: 5px; width: 640px; height: 300px; overflow: auto;">
<?php

/**
* Neat little stats page. Helps with development in some cases.
* @package	OpenBASE
* @author 	David Branco <David@NeoeliteUSA.com>
*/

set_time_limit(60);

class projectStats
{
    var $filesParsed = array();
    var $files = 0;
    var $dirs = 0;

    var $lines = 0;
    var $characters = 0;
    var $whitespace = 0;

    var $size = 0;

    var $extensions = array();
    var $extMatch = '';

	var $extFileCount = array('php'=>0, 'tpl'=>0, 'html'=>0, 'js'=>0, 'sql'=>0, 'tpl.html'=>0);

    function projectStats($dir, $ext = array('.*'))
    {
        $this->extensions = $ext;
        $this->extMatch = implode('|', $this->extensions);

        $this->parseDir($dir);
    }

    function parseDir($dirName)
    {
        $dir = opendir($dirName);
        while ($file = readdir($dir)) {

            if ($file[0] === '.') {
                continue;
            }
            $path = $dirName . '/' . $file;

            if (is_dir($path)) {
                ++$this->dirs;
                $this->parseDir($path);
            } else {
                if (!preg_match('/\.(?:' . $this->extMatch . ')$/i', $file)) {
                    continue;
                }

                ++$this->files;
                $filesParsed[] = $file;

				// count no of file extensions defined as keys in $extFileCount
				$extFile = substr($path,strrpos($path,'.')+1);
				if($extFile == 'html' && strpos($path, 'tpl') !== false)
				{
					$this->extFileCount['tpl.html'] += 1;
				}
				else
				{
					$this->extFileCount[$extFile] += 1;
				}

                $content = file($path);
                $this->lines += count($content);
                $this->size += filesize($path);

                for ($i = count($content); $i>0; --$i) {
                    $characters = strlen(preg_replace('/\s/i', '', $content[$i]));
                    $this->characters += $characters;
                    $this->whitespace += strlen($content[$i]) - $characters;
                }
            }
        }
    }
}

$stuff = new projectStats('.', array('php', 'tpl', 'sql', 'js', 'tpl.html', 'html'));

print "<p>There are <strong>".number_format($stuff->files)." files</strong> in <strong>".number_format($stuff->dirs)." directories</strong>,
totalling <strong>".number_format($stuff->size)." bytes <em>(".number_format(round($stuff->size / 1024))." kilobytes)</em></strong> - excluding image files.<br />
";
print "Comprised of:<br /><br />";
foreach($stuff->extFileCount as $key=>$val)
{
	if($val > 0)
	{
		print "<strong><em>".number_format($val)."</em> $key</strong> files<br />";
	}
}
print "<br />
This is <strong>" . number_format(round($stuff->size / $stuff->files, 2), 2) . " bytes</strong> per file, and
<strong>" . number_format(round($stuff->size / $stuff->dirs, 2), 2) . " bytes</strong> per directory.</p>
<p>These files contain <strong>".number_format($stuff->lines)." lines</strong>, including <strong>".number_format($stuff->whitespace)." characters</strong> of
whitespace, and <strong>".number_format($stuff->characters)." other characters</strong>.
The ratio of content to whitespace is <strong>".round(($stuff->characters/$stuff->whitespace), 2).":1</strong>.</p>
<p>Files used had to have one of the following extensions: <em>" . implode(', ', $stuff->extensions) . "</em>.</p>";

?>
</div>